OpenStreetMap
-------------

Register your client application under `My Settings`/`oauth settings`:

    https://www.openstreetmap.org/user/{Display Name}/oauth_clients

In this page you will get your key and secret

For more information:
OpenStreetMap OAuth documentation: https://wiki.openstreetmap.org/wiki/OAuth
